import { __decorate, __param } from 'tslib';
import { InjectionToken, Inject, Component, ɵɵdefineInjectable, ɵɵinject, Injectable, Input, Directive, NgModule } from '@angular/core';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { JwtHelperService, JwtModule } from '@auth0/angular-jwt';
import { Router } from '@angular/router';
import decode from 'jwt-decode';
import { Subject, throwError, BehaviorSubject, interval, of } from 'rxjs';
import { MAT_DIALOG_DATA, MatDialogRef, MatDialogModule } from '@angular/material/dialog';
import { MatButtonModule } from '@angular/material/button';
import { catchError, delayWhen, filter, take, concatMap, switchMap } from 'rxjs/operators';

const NGX_CORE_TOKEN = new InjectionToken('NGX_CORE_TOKEN');

let NgxCoreComponent = class NgxCoreComponent {
    constructor(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.authHost = this.ngxCoreConfig.authHost;
        this.apiHost = this.ngxCoreConfig.apiHost;
        this.project = this.ngxCoreConfig.project;
    }
    ngOnInit() {
    }
};
NgxCoreComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
];
NgxCoreComponent = __decorate([
    Component({
        selector: 'lib-ngx-core',
        template: `
  <div style="background: lightsalmon">
      <p> ngx-core works! </p>
      <p>{{ authHost }} </p>
      <p>{{ apiHost }} </p>
      <p>{{ project }} </p>
  </div>
    
  
  `
    }),
    __param(0, Inject(NGX_CORE_TOKEN))
], NgxCoreComponent);

let StorageService = class StorageService {
    constructor(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
    }
    // cookie
    setCookie(name, val) {
        const date = new Date();
        const value = val;
        // Set it expire in 7 days (nap*ora*perc*mp*ms)
        date.setTime(date.getTime() + (7 * 24 * 60 * 60 * 1000));
        // Set it
        document.cookie = `${this.ngxCoreConfig.project}-${name}` + '=' + encodeURI(value) + '; expires=' + date.toUTCString() + '; path=/';
    }
    /**
     * Returns with a cookie associated with the given name
     * @param name
     */
    getCookie(name) {
        const value = '; ' + document.cookie;
        const parts = decodeURI(value).split('; ' + `${this.ngxCoreConfig.project}-${name}` + '=');
        if (parts.length === 2) {
            return parts.pop().split(';').shift();
        }
    }
    /**
     * Deletes a cookie by name
     * @param name
     */
    deleteCookie(name) {
        const date = new Date();
        // Set it expire in -1 days
        date.setTime(date.getTime() + (-1 * 24 * 60 * 60 * 1000));
        // Set it
        document.cookie = `${this.ngxCoreConfig.project}-${name}` + '=; expires=' + date.toUTCString() + '; path=/';
    }
    /**
    * Deletes all cookies
    */
    clearCookies() {
        const cookies = document.cookie.split(";");
        for (var i = 0; i < cookies.length; i++) {
            var cookie = cookies[i];
            var eqPos = cookie.indexOf("=");
            var name = eqPos > -1 ? cookie.substr(0, eqPos) : cookie;
            document.cookie = name + "=;expires=Thu, 01 Jan 1970 00:00:00 GMT";
        }
    }
    // localStorage
    setStorage(name, val) {
        localStorage.setItem(`${this.ngxCoreConfig.project}-${name}`, val);
    }
    getStorage(name) {
        const item = localStorage.getItem(`${this.ngxCoreConfig.project}-${name}`);
        return item;
    }
    deleteStorage(name) {
        localStorage.removeItem(`${this.ngxCoreConfig.project}-${name}`);
    }
    clearStorage() {
        localStorage.clear();
    }
};
StorageService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
];
StorageService.ɵprov = ɵɵdefineInjectable({ factory: function StorageService_Factory() { return new StorageService(ɵɵinject(NGX_CORE_TOKEN)); }, token: StorageService, providedIn: "root" });
StorageService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(NGX_CORE_TOKEN))
], StorageService);

let AuthService = class AuthService {
    constructor(ngxCoreConfig, jwtHelper, storageService, router, http) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.jwtHelper = jwtHelper;
        this.storageService = storageService;
        this.router = router;
        this.http = http;
        this.subChange = new Subject();
    }
    /**
     * User has access to the path and valid token.
     * @param route
     */
    canActivate(route) {
        const expectedRole = route.data.expectedRole;
        const token = this.getToken();
        if (!token) {
            this.router.navigate(['']);
            return false;
        }
        else {
            const tokenPayload = decode(token);
            const userRole = tokenPayload.identity.role;
            if (!this.isAuthenticated() ||
                !expectedRole.includes(userRole)) {
                this.router.navigate(['']);
                return false;
            }
            return true;
        }
    }
    /**
     * User has valid token.
     */
    isAuthenticated() {
        const token = this.getToken();
        if (!token) {
            return false;
        }
        else {
            return !this.jwtHelper.isTokenExpired(token);
        }
    }
    /**
     * Returns user token.
     */
    getToken() {
        const token = this.storageService.getCookie('access_token');
        return token;
    }
    /**
     * Get a fresh token using the refresh token
     * @param url
     * @param data
     */
    postUserTokenRefresh(url, data) {
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    }
    /**
     * Get user role.
     */
    getRole() {
        const token = this.getToken();
        const role = token ? decode(token).identity.role : null;
        return role;
    }
    /**
     * Get username.
     */
    getUsername() {
        const token = this.getToken();
        const username = token ? decode(token).identity.username : null;
        return username;
    }
    /**
   * Get name.
   */
    getName() {
        const token = this.getToken();
        const name = token ? decode(token).identity.name : null;
        return name;
    }
    /**
    * Get user data.
    */
    getUserData() {
        const token = this.getToken();
        const usrData = token ? decode(token).identity : null;
        return usrData;
    }
    /**
     * Data change subject.
     * @param data
     */
    change(data) {
        this.subChange.next(data);
    }
    /**
     * User login.
     * @param url
     * @param data
     */
    login(url, data) {
        data['refreshType'] = this.ngxCoreConfig.refreshType;
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    }
    allUsers(url, data) {
        data['refreshType'] = this.ngxCoreConfig.refreshType;
        return this.http.get(this.ngxCoreConfig.authHost + url, { params: { data } });
    }
    /**
     * User logout, cookie and storage clear.
     * @param url
     * @param data
     */
    logout(url, data) {
        // this.storageService.clearStorage();
        // this.storageService.clearCookies();
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    }
    /**
     * User logout, cookie and storage clear.
     * @param url
     * @param data
     */
    post(url, data) {
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    }
};
AuthService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
    { type: JwtHelperService },
    { type: StorageService },
    { type: Router },
    { type: HttpClient }
];
AuthService.ɵprov = ɵɵdefineInjectable({ factory: function AuthService_Factory() { return new AuthService(ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(JwtHelperService), ɵɵinject(StorageService), ɵɵinject(Router), ɵɵinject(HttpClient)); }, token: AuthService, providedIn: "root" });
AuthService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(NGX_CORE_TOKEN))
], AuthService);

let PermissionDirective = class PermissionDirective {
    constructor(authService) {
        this.authService = authService;
        this.userRole = this.authService.getRole();
        if (this.hasPermission === undefined) {
            this.hasPermission = true;
        }
        if (this.arrPermission && this.userRole !== null) {
            this.setVisibilityByArrPerm();
        }
    }
    setVisibilityByArrPerm() {
        if (!this.arrPermission) {
            this.er.nativeElement.style.display = 'block';
        }
        else {
            if (this.hasPermission === true) {
                if (this.arrPermission.includes(this.userRole)) {
                    this.er.nativeElement.style.display = 'block';
                }
                else {
                    this.er.nativeElement.style.display = 'none';
                }
            }
            else {
                if (this.arrPermission.includes(this.userRole)) {
                    this.er.nativeElement.style.display = 'none';
                }
                else {
                    this.er.nativeElement.style.display = 'block';
                }
            }
        }
    }
};
PermissionDirective.ctorParameters = () => [
    { type: AuthService }
];
__decorate([
    Input('libPermission')
], PermissionDirective.prototype, "arrPermission", void 0);
__decorate([
    Input('hasPermission')
], PermissionDirective.prototype, "hasPermission", void 0);
PermissionDirective = __decorate([
    Directive({
        selector: '[libPermission]'
    })
], PermissionDirective);

let ConfirmDialogComponent = class ConfirmDialogComponent {
    constructor(message, dialogRef) {
        this.message = message;
        this.dialogRef = dialogRef;
    }
    ngOnInit() {
    }
};
ConfirmDialogComponent.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: MatDialogRef }
];
ConfirmDialogComponent = __decorate([
    Component({
        selector: 'lib-confirm-dialog',
        template: "<div mat-dialog-content>\r\n    {{ message }}\r\n  </div>\r\n  <div mat-dialog-actions>\r\n    <button mat-button [mat-dialog-close]=\"false\">Nem</button>\r\n    <button mat-button [mat-dialog-close]=\"true\" cdkFocusInitial>Igen</button>\r\n  </div>\r\n  ",
        styles: [""]
    }),
    __param(0, Inject(MAT_DIALOG_DATA))
], ConfirmDialogComponent);

var NgxCoreModule_1;
let NgxCoreModule = NgxCoreModule_1 = class NgxCoreModule {
    static forRoot(ngxCoreConfig) {
        return {
            ngModule: NgxCoreModule_1,
            providers: [
                {
                    provide: NGX_CORE_TOKEN,
                    useValue: ngxCoreConfig
                }
            ]
        };
    }
};
NgxCoreModule = NgxCoreModule_1 = __decorate([
    NgModule({
        declarations: [NgxCoreComponent, PermissionDirective, ConfirmDialogComponent],
        imports: [
            MatButtonModule,
            MatDialogModule,
            HttpClientModule,
            JwtModule.forRoot({
                config: {
                    tokenGetter: null,
                    whitelistedDomains: [],
                    blacklistedRoutes: []
                }
            }),
        ],
        exports: [NgxCoreComponent],
    })
], NgxCoreModule);

let ApiService = class ApiService {
    constructor(ngxCoreConfig, http) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.http = http;
    }
    /**
     * Http GET request.
     * @param url
     * @param data
     */
    get(url, data) {
        return this.http.get(this.ngxCoreConfig.apiHost + url, {
            params: data
        });
    }
    /**
     * Http PUT request.
     * @param url
     * @param data
     */
    put(url, data) {
        return this.http.put(this.ngxCoreConfig.apiHost + url, data);
    }
    /**
     * Http POST request.
     * @param url
     * @param data
     */
    post(url, data) {
        return this.http.post(this.ngxCoreConfig.apiHost + url, data);
    }
    /**
     * Http DELETE request.
     * @param url
     * @param data
     */
    delete(url, data) {
        return this.http.delete(this.ngxCoreConfig.apiHost + url, {
            params: data
        });
    }
};
ApiService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
    { type: HttpClient }
];
ApiService.ɵprov = ɵɵdefineInjectable({ factory: function ApiService_Factory() { return new ApiService(ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(HttpClient)); }, token: ApiService, providedIn: "root" });
ApiService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(NGX_CORE_TOKEN))
], ApiService);

let ErrorInterceptorService = class ErrorInterceptorService {
    constructor(
    //private snackBarService: SnackbarService,
    storageService, // -> authService
    router) {
        this.storageService = storageService;
        this.router = router;
    }
    intercept(request, next) {
        if (request.url.endsWith('login')) {
            return next.handle(request).pipe(catchError(err => {
                const error = err.error.message || err.statusText;
                return throwError(error);
            }));
        }
        else {
            if (this.storageService.getCookie('access_token') !== undefined) {
                return next.handle(request).pipe(catchError(err => {
                    const error = err.error.message || err.statusText;
                    return throwError(error);
                }));
            }
            else {
                this.router.navigate(['']);
                this.storageService.clearCookies();
                return next.handle(request).pipe(catchError(err => {
                    const error = err.error.message || err.statusText;
                    return throwError(error);
                }));
            }
        }
    }
};
ErrorInterceptorService.ctorParameters = () => [
    { type: StorageService },
    { type: Router }
];
ErrorInterceptorService.ɵprov = ɵɵdefineInjectable({ factory: function ErrorInterceptorService_Factory() { return new ErrorInterceptorService(ɵɵinject(StorageService), ɵɵinject(Router)); }, token: ErrorInterceptorService, providedIn: "root" });
ErrorInterceptorService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ErrorInterceptorService);

let JwtInterceptorService = class JwtInterceptorService {
    constructor(storageService, ngxCoreConfig, jwtHelper) {
        this.storageService = storageService;
        this.ngxCoreConfig = ngxCoreConfig;
        this.jwtHelper = jwtHelper;
    }
    intercept(request, next) {
        const token = this.storageService.getCookie('access_token');
        if (token) {
            if (token && !request.url.endsWith('token_refresh')) {
                request = request.clone({
                    setHeaders: {
                        Authorization: `Bearer ${token}`,
                        'Client': this.ngxCoreConfig.project
                        // 'Content-Type': 'application/json'
                    }
                });
            }
            else if (this.jwtHelper.isTokenExpired(token) && request.url.endsWith('token_refresh')) {
                const refreshToken = this.storageService.getCookie('refresh_token');
                request = request.clone({
                    setHeaders: {
                        Authorization: `Bearer ${refreshToken}`,
                        'Client': this.ngxCoreConfig.project
                        // 'Content-Type': 'application/json'
                    }
                });
            }
        }
        else {
            request = request.clone({
                setHeaders: {
                    'Client': this.ngxCoreConfig.project
                    // 'Content-Type': 'application/json'
                }
            });
        }
        return next.handle(request);
    }
};
JwtInterceptorService.ctorParameters = () => [
    { type: StorageService },
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
    { type: JwtHelperService }
];
JwtInterceptorService.ɵprov = ɵɵdefineInjectable({ factory: function JwtInterceptorService_Factory() { return new JwtInterceptorService(ɵɵinject(StorageService), ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(JwtHelperService)); }, token: JwtInterceptorService, providedIn: "root" });
JwtInterceptorService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(1, Inject(NGX_CORE_TOKEN))
], JwtInterceptorService);

let RefreshTokenInterceptor = class RefreshTokenInterceptor {
    constructor(auth, storageService, router, jwtHelper, ngxCoreConfig) {
        this.auth = auth;
        this.storageService = storageService;
        this.router = router;
        this.jwtHelper = jwtHelper;
        this.ngxCoreConfig = ngxCoreConfig;
        this.refreshTokenInProgress = false;
        this.refreshTokenSubject = new BehaviorSubject(null);
    }
    intercept(request, next) {
        return next.handle(request).pipe(catchError(error => {
            // We don't want to refresh token for some requests like login or refresh token itself
            // So we verify url and we throw an error if it's the case
            if (request.url.includes('token_refresh') ||
                request.url.includes('login')) {
                // We do another check to see if refresh token failed
                // In this case we want to logout user and to redirect it to login page
                if (request.url.includes('token_refresh')) {
                    this.auth.post('/users/logout_access', {});
                }
                return throwError(error);
            }
            // If error status is different than 401 we want to skip refresh token
            // So we check that and throw the error if it's the case
            if (error.status !== 401) {
                return throwError(error);
            }
            if (this.refreshTokenInProgress) {
                // If refreshTokenInProgress is true, we will wait until refreshTokenSubject has a non-null value
                // – which means the new token is ready and we can retry the request again
                return this.refreshTokenSubject.pipe(delayWhen(val => val ? interval(500) : of(!this.jwtHelper.isTokenExpired(this.auth.getToken()))), filter(token => token != null), take(1), concatMap(token => {
                    return next.handle(this.addAuthenticationToken(request));
                }));
            }
            else {
                if (this.ngxCoreConfig.refreshType === 0) {
                    this.refreshTokenInProgress = true;
                    // Set the refreshTokenSubject to null so that subsequent API calls will wait until the new token has been retrieved
                    this.refreshTokenSubject.next(null);
                    // Call auth.refreshAccessToken(this is an Observable that will be returned)
                    return this.auth.postUserTokenRefresh('/users/token_refresh', {}).pipe(switchMap((token) => {
                        // When the call to refreshToken completes we reset the refreshTokenInProgress to false
                        // for the next time the token needs to be refreshed
                        this.refreshTokenInProgress = false;
                        this.refreshTokenSubject.next(token['access_token']);
                        this.storageService.setCookie('access_token', token['access_token']);
                        return next.handle(this.addAuthenticationToken(request));
                    }), catchError((err) => {
                        this.refreshTokenInProgress = false;
                        this.auth.post('/users/logout_access', {});
                        return throwError(err);
                    }));
                    /* } else if (this.ngxCoreConfig.refreshType === '1') {
                      this.refreshTokenInProgress = true;
          
                      // Set the refreshTokenSubject to null so that subsequent API calls will wait until the new token has been retrieved
                      this.refreshTokenSubject.next(null);
          
                      let dialogResult = false;
          
                      const msg = 'Időtúllépés. Szeretne bejelentkezve maradni?';
                      const dlg = this.dialog.open(ConfirmDialogComponent, {
                        data: msg
                      });
          
                      dlg.afterClosed().subscribe(result => {
                        dialogResult = result;
                      });
          
                      setTimeout(() => {
                        dialogResult = true;
                      }, 2900);
          
                      return this.auth.postUserTokenRefresh('users/token_refresh', {}).pipe(
                        delayWhen(val => val ? interval(3000) : of(!dialogResult)),
                        switchMap((token: any) => {
                          // When the call to refreshToken completes we reset the refreshTokenInProgress to false
                          // for the next time the token needs to be refreshed
                          this.refreshTokenInProgress = false;
                          this.refreshTokenSubject.next(token['access_token']);
                          this.storageService.setCookie('access_token', token['access_token']);
                          return next.handle(this.addAuthenticationToken(request));
                        }),
                        catchError((err: any) => {
                          this.refreshTokenInProgress = false;
                          this.router.navigate(['']);
                          dlg.close();
                          this.storageService.clearCookies();
                          this.storageService.clearStorage();
                          this.auth.post('users/logout_access', {});
                          return throwError(err);
                        })); */
                }
                else {
                    this.router.navigate(['']);
                    this.storageService.clearCookies();
                    this.storageService.clearStorage();
                }
            }
        }));
    }
    addAuthenticationToken(request) {
        // Get access token from Local Storage
        const accessToken = this.auth.getToken();
        // If access token is null this means that user is not logged in
        // And we return the original request
        if (!accessToken) {
            return request;
        }
        // We clone the request, because the original request is immutable
        return request.clone({
            setHeaders: {
                Authorization: 'Bearer ' + this.auth.getToken()
            }
        });
    }
};
RefreshTokenInterceptor.ctorParameters = () => [
    { type: AuthService },
    { type: StorageService },
    { type: Router },
    { type: JwtHelperService },
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
];
RefreshTokenInterceptor = __decorate([
    Injectable(),
    __param(4, Inject(NGX_CORE_TOKEN))
], RefreshTokenInterceptor);

let AppStateService = class AppStateService {
    constructor(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.asObj = new Object();
        this.datachange = new BehaviorSubject(null);
    }
    /**
    * Sets the viewState object. Loads the project name and loggedIn = false if first init,
    * else loads it from the localStorage.
    */
    setAppState() {
        if (!localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`)) {
            this.asObj['name'] = this.ngxCoreConfig.project;
            this.asObj['loggedIn'] = false;
            const objToJson = JSON.stringify(this.asObj);
            console.log(objToJson);
            console.log(this.asObj);
            localStorage.setItem(`${this.ngxCoreConfig.project}-app-state`, objToJson);
            this.datachange.next(this.asObj);
        }
        else {
            this.asObj = localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`)
                ? JSON.parse(localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`))
                : this.asObj;
            console.log(localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`));
            this.datachange.next(this.asObj);
        }
    }
    /**
    * Returns the appState object.
    */
    getAppState() {
        this.asObj = localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`)
            ? JSON.parse(localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`))
            : this.asObj;
        return this.asObj;
    }
    /**
     * Returns the value of the given key from the asObj.
     */
    getAppStateByKey(key) {
        this.asObj = localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`)
            ? JSON.parse(localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`))
            : this.asObj;
        return this.asObj[key];
    }
    /**
     * Changes the provided key-value pair in the asObj.
     * @param obj
     */
    changeAppState(obj) {
        this.asObj = localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`)
            ? JSON.parse(localStorage.getItem(`${this.ngxCoreConfig.project}-app-state`))
            : this.asObj;
        for (const key in obj) {
            if (obj.hasOwnProperty(key)) {
                const element = obj[key];
                this.asObj[key] = element;
            }
        }
        const objToJson = JSON.stringify(this.asObj);
        localStorage.setItem(`${this.ngxCoreConfig.project}-app-state`, objToJson);
        this.datachange.next(obj);
    }
};
AppStateService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
];
AppStateService.ɵprov = ɵɵdefineInjectable({ factory: function AppStateService_Factory() { return new AppStateService(ɵɵinject(NGX_CORE_TOKEN)); }, token: AppStateService, providedIn: "root" });
AppStateService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(NGX_CORE_TOKEN))
], AppStateService);

let ViewStateService = class ViewStateService {
    //datachange: Subject<any> = new Subject<any>();
    constructor() {
        //mapObj = new Map();
        this.vsObj = new Object();
        this.dataChange = new Subject();
    }
    /**
     * Returns the viewState object. (Map<String, any>)
     */
    getViewState() {
        //const vs = JSON.parse(JSON.stringify([...this.mapObj]));
        const vs = JSON.parse(JSON.stringify(this.vsObj));
        return vs;
    }
    /**
     * Sets the viewState - only use it in the view constructor!
     */
    setViewState(obj) {
        /*
        this.mapObj.set('view', obj.view);
        this.mapObj.set('history', []);
        this.datachange.next(obj);*/
        this.vsObj['view'] = obj.view;
        this.vsObj['history'] = [];
        this.dataChange.next(this.vsObj);
    }
    /**
     * Returns data that maches the given parameter.
     * @param key Data name.
     */
    getViewStateByKey(key) {
        //return this.mapObj.get(key);
        return this.vsObj[`${key}`];
    }
    /**
     * Returns the current view.
     */
    getView() {
        // return this.mapObj.get('view');
        return this.vsObj['view'];
    }
    /**
     * Changes the view state. Sets the goven data and history, emits the current change.
     * @param obj Current change.
     * @param history History - name of the event.
     */
    changeViewState(obj, history) {
        /*history = history ? history : `${this.mapObj.get('view')}Event`;
        for (const key in obj) {
          if (obj.hasOwnProperty(key)) {
            const element = obj[key];
            this.mapObj.set(`${key}`, element);
            this.mapObj.get('history').push({event: history, value: element});
          }
        }
        this.datachange.next(obj);*/
        history = history ? history : `${this.vsObj['view']}Event`;
        for (const key in obj) {
            if (obj.hasOwnProperty(key)) {
                const element = obj[key];
                this.vsObj[`${key}`] = element;
                this.vsObj['history'].push({ event: history, value: element });
            }
        }
        obj.view = this.vsObj.view;
        this.dataChange.next(obj);
    }
};
ViewStateService.ɵprov = ɵɵdefineInjectable({ factory: function ViewStateService_Factory() { return new ViewStateService(); }, token: ViewStateService, providedIn: "root" });
ViewStateService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ViewStateService);

/*
 * Public API Surface of ngx-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ApiService, AppStateService, AuthService, ErrorInterceptorService, JwtInterceptorService, NgxCoreModule, PermissionDirective, RefreshTokenInterceptor, StorageService, ViewStateService, NgxCoreComponent as ɵa, NGX_CORE_TOKEN as ɵb, ConfirmDialogComponent as ɵc };
//# sourceMappingURL=ngx-core-services.js.map
