import { __decorate, __param } from 'tslib';
import { InjectionToken, Inject, Component, ɵɵdefineInjectable, ɵɵinject, Injectable, Input, Directive, NgModule } from '@angular/core';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { JwtHelperService, JwtModule } from '@auth0/angular-jwt';
import { Router } from '@angular/router';
import decode from 'jwt-decode';
import { Subject, throwError, BehaviorSubject, interval, of } from 'rxjs';
import { MAT_DIALOG_DATA, MatDialogRef, MatDialogModule } from '@angular/material/dialog';
import { MatButtonModule } from '@angular/material/button';
import { catchError, delayWhen, filter, take, concatMap, switchMap } from 'rxjs/operators';

var NGX_CORE_TOKEN = new InjectionToken('NGX_CORE_TOKEN');

var NgxCoreComponent = /** @class */ (function () {
    function NgxCoreComponent(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.authHost = this.ngxCoreConfig.authHost;
        this.apiHost = this.ngxCoreConfig.apiHost;
        this.project = this.ngxCoreConfig.project;
    }
    NgxCoreComponent.prototype.ngOnInit = function () {
    };
    NgxCoreComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
    ]; };
    NgxCoreComponent = __decorate([
        Component({
            selector: 'lib-ngx-core',
            template: "\n  <div style=\"background: lightsalmon\">\n      <p> ngx-core works! </p>\n      <p>{{ authHost }} </p>\n      <p>{{ apiHost }} </p>\n      <p>{{ project }} </p>\n  </div>\n    \n  \n  "
        }),
        __param(0, Inject(NGX_CORE_TOKEN))
    ], NgxCoreComponent);
    return NgxCoreComponent;
}());

var StorageService = /** @class */ (function () {
    function StorageService(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
    }
    // cookie
    StorageService.prototype.setCookie = function (name, val) {
        var date = new Date();
        var value = val;
        // Set it expire in 7 days (nap*ora*perc*mp*ms)
        date.setTime(date.getTime() + (7 * 24 * 60 * 60 * 1000));
        // Set it
        document.cookie = this.ngxCoreConfig.project + "-" + name + '=' + encodeURI(value) + '; expires=' + date.toUTCString() + '; path=/';
    };
    /**
     * Returns with a cookie associated with the given name
     * @param name
     */
    StorageService.prototype.getCookie = function (name) {
        var value = '; ' + document.cookie;
        var parts = decodeURI(value).split('; ' + (this.ngxCoreConfig.project + "-" + name) + '=');
        if (parts.length === 2) {
            return parts.pop().split(';').shift();
        }
    };
    /**
     * Deletes a cookie by name
     * @param name
     */
    StorageService.prototype.deleteCookie = function (name) {
        var date = new Date();
        // Set it expire in -1 days
        date.setTime(date.getTime() + (-1 * 24 * 60 * 60 * 1000));
        // Set it
        document.cookie = this.ngxCoreConfig.project + "-" + name + '=; expires=' + date.toUTCString() + '; path=/';
    };
    /**
    * Deletes all cookies
    */
    StorageService.prototype.clearCookies = function () {
        var cookies = document.cookie.split(";");
        for (var i = 0; i < cookies.length; i++) {
            var cookie = cookies[i];
            var eqPos = cookie.indexOf("=");
            var name = eqPos > -1 ? cookie.substr(0, eqPos) : cookie;
            document.cookie = name + "=;expires=Thu, 01 Jan 1970 00:00:00 GMT";
        }
    };
    // localStorage
    StorageService.prototype.setStorage = function (name, val) {
        localStorage.setItem(this.ngxCoreConfig.project + "-" + name, val);
    };
    StorageService.prototype.getStorage = function (name) {
        var item = localStorage.getItem(this.ngxCoreConfig.project + "-" + name);
        return item;
    };
    StorageService.prototype.deleteStorage = function (name) {
        localStorage.removeItem(this.ngxCoreConfig.project + "-" + name);
    };
    StorageService.prototype.clearStorage = function () {
        localStorage.clear();
    };
    StorageService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
    ]; };
    StorageService.ɵprov = ɵɵdefineInjectable({ factory: function StorageService_Factory() { return new StorageService(ɵɵinject(NGX_CORE_TOKEN)); }, token: StorageService, providedIn: "root" });
    StorageService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(NGX_CORE_TOKEN))
    ], StorageService);
    return StorageService;
}());

var AuthService = /** @class */ (function () {
    function AuthService(ngxCoreConfig, jwtHelper, storageService, router, http) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.jwtHelper = jwtHelper;
        this.storageService = storageService;
        this.router = router;
        this.http = http;
        this.subChange = new Subject();
    }
    /**
     * User has access to the path and valid token.
     * @param route
     */
    AuthService.prototype.canActivate = function (route) {
        var expectedRole = route.data.expectedRole;
        var token = this.getToken();
        if (!token) {
            this.router.navigate(['']);
            return false;
        }
        else {
            var tokenPayload = decode(token);
            var userRole = tokenPayload.identity.role;
            if (!this.isAuthenticated() ||
                !expectedRole.includes(userRole)) {
                this.router.navigate(['']);
                return false;
            }
            return true;
        }
    };
    /**
     * User has valid token.
     */
    AuthService.prototype.isAuthenticated = function () {
        var token = this.getToken();
        if (!token) {
            return false;
        }
        else {
            return !this.jwtHelper.isTokenExpired(token);
        }
    };
    /**
     * Returns user token.
     */
    AuthService.prototype.getToken = function () {
        var token = this.storageService.getCookie('access_token');
        return token;
    };
    /**
     * Get a fresh token using the refresh token
     * @param url
     * @param data
     */
    AuthService.prototype.postUserTokenRefresh = function (url, data) {
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    };
    /**
     * Get user role.
     */
    AuthService.prototype.getRole = function () {
        var token = this.getToken();
        var role = token ? decode(token).identity.role : null;
        return role;
    };
    /**
     * Get username.
     */
    AuthService.prototype.getUsername = function () {
        var token = this.getToken();
        var username = token ? decode(token).identity.username : null;
        return username;
    };
    /**
   * Get name.
   */
    AuthService.prototype.getName = function () {
        var token = this.getToken();
        var name = token ? decode(token).identity.name : null;
        return name;
    };
    /**
    * Get user data.
    */
    AuthService.prototype.getUserData = function () {
        var token = this.getToken();
        var usrData = token ? decode(token).identity : null;
        return usrData;
    };
    /**
     * Data change subject.
     * @param data
     */
    AuthService.prototype.change = function (data) {
        this.subChange.next(data);
    };
    /**
     * User login.
     * @param url
     * @param data
     */
    AuthService.prototype.login = function (url, data) {
        data['refreshType'] = this.ngxCoreConfig.refreshType;
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    };
    AuthService.prototype.allUsers = function (url, data) {
        data['refreshType'] = this.ngxCoreConfig.refreshType;
        return this.http.get(this.ngxCoreConfig.authHost + url, { params: { data: data } });
    };
    /**
     * User logout, cookie and storage clear.
     * @param url
     * @param data
     */
    AuthService.prototype.logout = function (url, data) {
        // this.storageService.clearStorage();
        // this.storageService.clearCookies();
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    };
    /**
     * User logout, cookie and storage clear.
     * @param url
     * @param data
     */
    AuthService.prototype.post = function (url, data) {
        return this.http.post(this.ngxCoreConfig.authHost + url, data);
    };
    AuthService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
        { type: JwtHelperService },
        { type: StorageService },
        { type: Router },
        { type: HttpClient }
    ]; };
    AuthService.ɵprov = ɵɵdefineInjectable({ factory: function AuthService_Factory() { return new AuthService(ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(JwtHelperService), ɵɵinject(StorageService), ɵɵinject(Router), ɵɵinject(HttpClient)); }, token: AuthService, providedIn: "root" });
    AuthService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(NGX_CORE_TOKEN))
    ], AuthService);
    return AuthService;
}());

var PermissionDirective = /** @class */ (function () {
    function PermissionDirective(authService) {
        this.authService = authService;
        this.userRole = this.authService.getRole();
        if (this.hasPermission === undefined) {
            this.hasPermission = true;
        }
        if (this.arrPermission && this.userRole !== null) {
            this.setVisibilityByArrPerm();
        }
    }
    PermissionDirective.prototype.setVisibilityByArrPerm = function () {
        if (!this.arrPermission) {
            this.er.nativeElement.style.display = 'block';
        }
        else {
            if (this.hasPermission === true) {
                if (this.arrPermission.includes(this.userRole)) {
                    this.er.nativeElement.style.display = 'block';
                }
                else {
                    this.er.nativeElement.style.display = 'none';
                }
            }
            else {
                if (this.arrPermission.includes(this.userRole)) {
                    this.er.nativeElement.style.display = 'none';
                }
                else {
                    this.er.nativeElement.style.display = 'block';
                }
            }
        }
    };
    PermissionDirective.ctorParameters = function () { return [
        { type: AuthService }
    ]; };
    __decorate([
        Input('libPermission')
    ], PermissionDirective.prototype, "arrPermission", void 0);
    __decorate([
        Input('hasPermission')
    ], PermissionDirective.prototype, "hasPermission", void 0);
    PermissionDirective = __decorate([
        Directive({
            selector: '[libPermission]'
        })
    ], PermissionDirective);
    return PermissionDirective;
}());

var ConfirmDialogComponent = /** @class */ (function () {
    function ConfirmDialogComponent(message, dialogRef) {
        this.message = message;
        this.dialogRef = dialogRef;
    }
    ConfirmDialogComponent.prototype.ngOnInit = function () {
    };
    ConfirmDialogComponent.ctorParameters = function () { return [
        { type: String, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
        { type: MatDialogRef }
    ]; };
    ConfirmDialogComponent = __decorate([
        Component({
            selector: 'lib-confirm-dialog',
            template: "<div mat-dialog-content>\r\n    {{ message }}\r\n  </div>\r\n  <div mat-dialog-actions>\r\n    <button mat-button [mat-dialog-close]=\"false\">Nem</button>\r\n    <button mat-button [mat-dialog-close]=\"true\" cdkFocusInitial>Igen</button>\r\n  </div>\r\n  ",
            styles: [""]
        }),
        __param(0, Inject(MAT_DIALOG_DATA))
    ], ConfirmDialogComponent);
    return ConfirmDialogComponent;
}());

var NgxCoreModule = /** @class */ (function () {
    function NgxCoreModule() {
    }
    NgxCoreModule_1 = NgxCoreModule;
    NgxCoreModule.forRoot = function (ngxCoreConfig) {
        return {
            ngModule: NgxCoreModule_1,
            providers: [
                {
                    provide: NGX_CORE_TOKEN,
                    useValue: ngxCoreConfig
                }
            ]
        };
    };
    var NgxCoreModule_1;
    NgxCoreModule = NgxCoreModule_1 = __decorate([
        NgModule({
            declarations: [NgxCoreComponent, PermissionDirective, ConfirmDialogComponent],
            imports: [
                MatButtonModule,
                MatDialogModule,
                HttpClientModule,
                JwtModule.forRoot({
                    config: {
                        tokenGetter: null,
                        whitelistedDomains: [],
                        blacklistedRoutes: []
                    }
                }),
            ],
            exports: [NgxCoreComponent],
        })
    ], NgxCoreModule);
    return NgxCoreModule;
}());

var ApiService = /** @class */ (function () {
    function ApiService(ngxCoreConfig, http) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.http = http;
    }
    /**
     * Http GET request.
     * @param url
     * @param data
     */
    ApiService.prototype.get = function (url, data) {
        return this.http.get(this.ngxCoreConfig.apiHost + url, {
            params: data
        });
    };
    /**
     * Http PUT request.
     * @param url
     * @param data
     */
    ApiService.prototype.put = function (url, data) {
        return this.http.put(this.ngxCoreConfig.apiHost + url, data);
    };
    /**
     * Http POST request.
     * @param url
     * @param data
     */
    ApiService.prototype.post = function (url, data) {
        return this.http.post(this.ngxCoreConfig.apiHost + url, data);
    };
    /**
     * Http DELETE request.
     * @param url
     * @param data
     */
    ApiService.prototype.delete = function (url, data) {
        return this.http.delete(this.ngxCoreConfig.apiHost + url, {
            params: data
        });
    };
    ApiService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
        { type: HttpClient }
    ]; };
    ApiService.ɵprov = ɵɵdefineInjectable({ factory: function ApiService_Factory() { return new ApiService(ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(HttpClient)); }, token: ApiService, providedIn: "root" });
    ApiService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(NGX_CORE_TOKEN))
    ], ApiService);
    return ApiService;
}());

var ErrorInterceptorService = /** @class */ (function () {
    function ErrorInterceptorService(
    //private snackBarService: SnackbarService,
    storageService, // -> authService
    router) {
        this.storageService = storageService;
        this.router = router;
    }
    ErrorInterceptorService.prototype.intercept = function (request, next) {
        if (request.url.endsWith('login')) {
            return next.handle(request).pipe(catchError(function (err) {
                var error = err.error.message || err.statusText;
                return throwError(error);
            }));
        }
        else {
            if (this.storageService.getCookie('access_token') !== undefined) {
                return next.handle(request).pipe(catchError(function (err) {
                    var error = err.error.message || err.statusText;
                    return throwError(error);
                }));
            }
            else {
                this.router.navigate(['']);
                this.storageService.clearCookies();
                return next.handle(request).pipe(catchError(function (err) {
                    var error = err.error.message || err.statusText;
                    return throwError(error);
                }));
            }
        }
    };
    ErrorInterceptorService.ctorParameters = function () { return [
        { type: StorageService },
        { type: Router }
    ]; };
    ErrorInterceptorService.ɵprov = ɵɵdefineInjectable({ factory: function ErrorInterceptorService_Factory() { return new ErrorInterceptorService(ɵɵinject(StorageService), ɵɵinject(Router)); }, token: ErrorInterceptorService, providedIn: "root" });
    ErrorInterceptorService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], ErrorInterceptorService);
    return ErrorInterceptorService;
}());

var JwtInterceptorService = /** @class */ (function () {
    function JwtInterceptorService(storageService, ngxCoreConfig, jwtHelper) {
        this.storageService = storageService;
        this.ngxCoreConfig = ngxCoreConfig;
        this.jwtHelper = jwtHelper;
    }
    JwtInterceptorService.prototype.intercept = function (request, next) {
        var token = this.storageService.getCookie('access_token');
        if (token) {
            if (token && !request.url.endsWith('token_refresh')) {
                request = request.clone({
                    setHeaders: {
                        Authorization: "Bearer " + token,
                        'Client': this.ngxCoreConfig.project
                        // 'Content-Type': 'application/json'
                    }
                });
            }
            else if (this.jwtHelper.isTokenExpired(token) && request.url.endsWith('token_refresh')) {
                var refreshToken = this.storageService.getCookie('refresh_token');
                request = request.clone({
                    setHeaders: {
                        Authorization: "Bearer " + refreshToken,
                        'Client': this.ngxCoreConfig.project
                        // 'Content-Type': 'application/json'
                    }
                });
            }
        }
        else {
            request = request.clone({
                setHeaders: {
                    'Client': this.ngxCoreConfig.project
                    // 'Content-Type': 'application/json'
                }
            });
        }
        return next.handle(request);
    };
    JwtInterceptorService.ctorParameters = function () { return [
        { type: StorageService },
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] },
        { type: JwtHelperService }
    ]; };
    JwtInterceptorService.ɵprov = ɵɵdefineInjectable({ factory: function JwtInterceptorService_Factory() { return new JwtInterceptorService(ɵɵinject(StorageService), ɵɵinject(NGX_CORE_TOKEN), ɵɵinject(JwtHelperService)); }, token: JwtInterceptorService, providedIn: "root" });
    JwtInterceptorService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(1, Inject(NGX_CORE_TOKEN))
    ], JwtInterceptorService);
    return JwtInterceptorService;
}());

var RefreshTokenInterceptor = /** @class */ (function () {
    function RefreshTokenInterceptor(auth, storageService, router, jwtHelper, ngxCoreConfig) {
        this.auth = auth;
        this.storageService = storageService;
        this.router = router;
        this.jwtHelper = jwtHelper;
        this.ngxCoreConfig = ngxCoreConfig;
        this.refreshTokenInProgress = false;
        this.refreshTokenSubject = new BehaviorSubject(null);
    }
    RefreshTokenInterceptor.prototype.intercept = function (request, next) {
        var _this = this;
        return next.handle(request).pipe(catchError(function (error) {
            // We don't want to refresh token for some requests like login or refresh token itself
            // So we verify url and we throw an error if it's the case
            if (request.url.includes('token_refresh') ||
                request.url.includes('login')) {
                // We do another check to see if refresh token failed
                // In this case we want to logout user and to redirect it to login page
                if (request.url.includes('token_refresh')) {
                    _this.auth.post('/users/logout_access', {});
                }
                return throwError(error);
            }
            // If error status is different than 401 we want to skip refresh token
            // So we check that and throw the error if it's the case
            if (error.status !== 401) {
                return throwError(error);
            }
            if (_this.refreshTokenInProgress) {
                // If refreshTokenInProgress is true, we will wait until refreshTokenSubject has a non-null value
                // – which means the new token is ready and we can retry the request again
                return _this.refreshTokenSubject.pipe(delayWhen(function (val) { return val ? interval(500) : of(!_this.jwtHelper.isTokenExpired(_this.auth.getToken())); }), filter(function (token) { return token != null; }), take(1), concatMap(function (token) {
                    return next.handle(_this.addAuthenticationToken(request));
                }));
            }
            else {
                if (_this.ngxCoreConfig.refreshType === 0) {
                    _this.refreshTokenInProgress = true;
                    // Set the refreshTokenSubject to null so that subsequent API calls will wait until the new token has been retrieved
                    _this.refreshTokenSubject.next(null);
                    // Call auth.refreshAccessToken(this is an Observable that will be returned)
                    return _this.auth.postUserTokenRefresh('/users/token_refresh', {}).pipe(switchMap(function (token) {
                        // When the call to refreshToken completes we reset the refreshTokenInProgress to false
                        // for the next time the token needs to be refreshed
                        _this.refreshTokenInProgress = false;
                        _this.refreshTokenSubject.next(token['access_token']);
                        _this.storageService.setCookie('access_token', token['access_token']);
                        return next.handle(_this.addAuthenticationToken(request));
                    }), catchError(function (err) {
                        _this.refreshTokenInProgress = false;
                        _this.auth.post('/users/logout_access', {});
                        return throwError(err);
                    }));
                    /* } else if (this.ngxCoreConfig.refreshType === '1') {
                      this.refreshTokenInProgress = true;
          
                      // Set the refreshTokenSubject to null so that subsequent API calls will wait until the new token has been retrieved
                      this.refreshTokenSubject.next(null);
          
                      let dialogResult = false;
          
                      const msg = 'Időtúllépés. Szeretne bejelentkezve maradni?';
                      const dlg = this.dialog.open(ConfirmDialogComponent, {
                        data: msg
                      });
          
                      dlg.afterClosed().subscribe(result => {
                        dialogResult = result;
                      });
          
                      setTimeout(() => {
                        dialogResult = true;
                      }, 2900);
          
                      return this.auth.postUserTokenRefresh('users/token_refresh', {}).pipe(
                        delayWhen(val => val ? interval(3000) : of(!dialogResult)),
                        switchMap((token: any) => {
                          // When the call to refreshToken completes we reset the refreshTokenInProgress to false
                          // for the next time the token needs to be refreshed
                          this.refreshTokenInProgress = false;
                          this.refreshTokenSubject.next(token['access_token']);
                          this.storageService.setCookie('access_token', token['access_token']);
                          return next.handle(this.addAuthenticationToken(request));
                        }),
                        catchError((err: any) => {
                          this.refreshTokenInProgress = false;
                          this.router.navigate(['']);
                          dlg.close();
                          this.storageService.clearCookies();
                          this.storageService.clearStorage();
                          this.auth.post('users/logout_access', {});
                          return throwError(err);
                        })); */
                }
                else {
                    _this.router.navigate(['']);
                    _this.storageService.clearCookies();
                    _this.storageService.clearStorage();
                }
            }
        }));
    };
    RefreshTokenInterceptor.prototype.addAuthenticationToken = function (request) {
        // Get access token from Local Storage
        var accessToken = this.auth.getToken();
        // If access token is null this means that user is not logged in
        // And we return the original request
        if (!accessToken) {
            return request;
        }
        // We clone the request, because the original request is immutable
        return request.clone({
            setHeaders: {
                Authorization: 'Bearer ' + this.auth.getToken()
            }
        });
    };
    RefreshTokenInterceptor.ctorParameters = function () { return [
        { type: AuthService },
        { type: StorageService },
        { type: Router },
        { type: JwtHelperService },
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
    ]; };
    RefreshTokenInterceptor = __decorate([
        Injectable(),
        __param(4, Inject(NGX_CORE_TOKEN))
    ], RefreshTokenInterceptor);
    return RefreshTokenInterceptor;
}());

var AppStateService = /** @class */ (function () {
    function AppStateService(ngxCoreConfig) {
        this.ngxCoreConfig = ngxCoreConfig;
        this.asObj = new Object();
        this.datachange = new BehaviorSubject(null);
    }
    /**
    * Sets the viewState object. Loads the project name and loggedIn = false if first init,
    * else loads it from the localStorage.
    */
    AppStateService.prototype.setAppState = function () {
        if (!localStorage.getItem(this.ngxCoreConfig.project + "-app-state")) {
            this.asObj['name'] = this.ngxCoreConfig.project;
            this.asObj['loggedIn'] = false;
            var objToJson = JSON.stringify(this.asObj);
            console.log(objToJson);
            console.log(this.asObj);
            localStorage.setItem(this.ngxCoreConfig.project + "-app-state", objToJson);
            this.datachange.next(this.asObj);
        }
        else {
            this.asObj = localStorage.getItem(this.ngxCoreConfig.project + "-app-state")
                ? JSON.parse(localStorage.getItem(this.ngxCoreConfig.project + "-app-state"))
                : this.asObj;
            console.log(localStorage.getItem(this.ngxCoreConfig.project + "-app-state"));
            this.datachange.next(this.asObj);
        }
    };
    /**
    * Returns the appState object.
    */
    AppStateService.prototype.getAppState = function () {
        this.asObj = localStorage.getItem(this.ngxCoreConfig.project + "-app-state")
            ? JSON.parse(localStorage.getItem(this.ngxCoreConfig.project + "-app-state"))
            : this.asObj;
        return this.asObj;
    };
    /**
     * Returns the value of the given key from the asObj.
     */
    AppStateService.prototype.getAppStateByKey = function (key) {
        this.asObj = localStorage.getItem(this.ngxCoreConfig.project + "-app-state")
            ? JSON.parse(localStorage.getItem(this.ngxCoreConfig.project + "-app-state"))
            : this.asObj;
        return this.asObj[key];
    };
    /**
     * Changes the provided key-value pair in the asObj.
     * @param obj
     */
    AppStateService.prototype.changeAppState = function (obj) {
        this.asObj = localStorage.getItem(this.ngxCoreConfig.project + "-app-state")
            ? JSON.parse(localStorage.getItem(this.ngxCoreConfig.project + "-app-state"))
            : this.asObj;
        for (var key in obj) {
            if (obj.hasOwnProperty(key)) {
                var element = obj[key];
                this.asObj[key] = element;
            }
        }
        var objToJson = JSON.stringify(this.asObj);
        localStorage.setItem(this.ngxCoreConfig.project + "-app-state", objToJson);
        this.datachange.next(obj);
    };
    AppStateService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [NGX_CORE_TOKEN,] }] }
    ]; };
    AppStateService.ɵprov = ɵɵdefineInjectable({ factory: function AppStateService_Factory() { return new AppStateService(ɵɵinject(NGX_CORE_TOKEN)); }, token: AppStateService, providedIn: "root" });
    AppStateService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(NGX_CORE_TOKEN))
    ], AppStateService);
    return AppStateService;
}());

var ViewStateService = /** @class */ (function () {
    //datachange: Subject<any> = new Subject<any>();
    function ViewStateService() {
        //mapObj = new Map();
        this.vsObj = new Object();
        this.dataChange = new Subject();
    }
    /**
     * Returns the viewState object. (Map<String, any>)
     */
    ViewStateService.prototype.getViewState = function () {
        //const vs = JSON.parse(JSON.stringify([...this.mapObj]));
        var vs = JSON.parse(JSON.stringify(this.vsObj));
        return vs;
    };
    /**
     * Sets the viewState - only use it in the view constructor!
     */
    ViewStateService.prototype.setViewState = function (obj) {
        /*
        this.mapObj.set('view', obj.view);
        this.mapObj.set('history', []);
        this.datachange.next(obj);*/
        this.vsObj['view'] = obj.view;
        this.vsObj['history'] = [];
        this.dataChange.next(this.vsObj);
    };
    /**
     * Returns data that maches the given parameter.
     * @param key Data name.
     */
    ViewStateService.prototype.getViewStateByKey = function (key) {
        //return this.mapObj.get(key);
        return this.vsObj["" + key];
    };
    /**
     * Returns the current view.
     */
    ViewStateService.prototype.getView = function () {
        // return this.mapObj.get('view');
        return this.vsObj['view'];
    };
    /**
     * Changes the view state. Sets the goven data and history, emits the current change.
     * @param obj Current change.
     * @param history History - name of the event.
     */
    ViewStateService.prototype.changeViewState = function (obj, history) {
        /*history = history ? history : `${this.mapObj.get('view')}Event`;
        for (const key in obj) {
          if (obj.hasOwnProperty(key)) {
            const element = obj[key];
            this.mapObj.set(`${key}`, element);
            this.mapObj.get('history').push({event: history, value: element});
          }
        }
        this.datachange.next(obj);*/
        history = history ? history : this.vsObj['view'] + "Event";
        for (var key in obj) {
            if (obj.hasOwnProperty(key)) {
                var element = obj[key];
                this.vsObj["" + key] = element;
                this.vsObj['history'].push({ event: history, value: element });
            }
        }
        obj.view = this.vsObj.view;
        this.dataChange.next(obj);
    };
    ViewStateService.ɵprov = ɵɵdefineInjectable({ factory: function ViewStateService_Factory() { return new ViewStateService(); }, token: ViewStateService, providedIn: "root" });
    ViewStateService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], ViewStateService);
    return ViewStateService;
}());

/*
 * Public API Surface of ngx-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ApiService, AppStateService, AuthService, ErrorInterceptorService, JwtInterceptorService, NgxCoreModule, PermissionDirective, RefreshTokenInterceptor, StorageService, ViewStateService, NgxCoreComponent as ɵa, NGX_CORE_TOKEN as ɵb, ConfirmDialogComponent as ɵc };
//# sourceMappingURL=ngx-core-services.js.map
